from pypjua.clients.cpim import MessageCPIMParser
from msrplib import protocol
from eventlet import api
from time import time, strftime
from os.path import expanduser
from msrplib.util import random_string
from msrplib import protocol

def stamp():
    return strftime('%H:%M:%S.')+'%.3d'%(time()%1*1000)

class SockInt4MSRP:
    def __init__(self, session, debug = None):
        self.session = session
        self.debug   = debug
        if debug:
            self.sent     = 0
            self.received = 0
            self.log      = file(expanduser('~/siplogs/' + debug + '-' + stamp() + '.log'), 'w')

    def recv(self, amount = 1536):
        while True: # Sometimes empty messages are read !?
                    # Loop until we have actually data.
            chunk = self.session.msrp.receive_chunk()
            if chunk is None:
                data = ''
            elif chunk.content_type == 'message/cpim':
                headers, data = MessageCPIMParser.parse_string(chunk.data)
            else:
                data = chunk.data
            if data != '':
                break

        if self.debug:
            nl = data.find('\n') + 1
            ln = data[:nl]
            data = data[nl:]
            self.log.write('%s %s recv%5d%6d: %s' % (
                self.debug, stamp(), self.received, len(data), ln)
            )
            if not data:
                self.log.write('\n')
            self.log.flush()
            self.received += 1
        return data
    
    def send(self, data, content_type = 'application/x-rfb'):
        msrp = self.session.msrp
        if self.debug:
            ln = '%s %s send%5d%6d\n' % (
                self.debug, stamp(), self.sent, len(data)
            )
            sent = self.sent
            self.sent += 1
            self.log.write(ln)
            self.log.flush()
            msrp.deliver_message(ln + data, content_type)
            #msrp.send_message(ln + data, content_type)
            self.log.write('%s %s sent%5d\n' % (' '*len(self.debug), stamp(), sent))
            self.log.flush()
        else:
            msrp.deliver_message(data, content_type)
            #msrp.send_message(data, content_type)
        return len(data) # everything is always sent
       
    def close(self):
        if self.debug:
            self.log.write('%s %s fini sent: %d, received: %d\n' % (self.debug, stamp(), self.sent, self.received))
            self.log.flush()
            #self.log.close() # FIXME! Logs on the server 
                              #        site get closed twice
        return self.session.end()

